# -*- coding: utf-8 -*-
# $Id: fi.py 7119 2011-09-02 13:00:23Z milde $
# Author: Asko Soukka <asko.soukka@iki.fi>
# Copyright: This module has been placed in the public domain.

# New language mappings are welcome.  Before doing a new translation, please
# read <http://docutils.sf.net/docs/howto/i18n.html>.  Two files must be
# translated for each language: one in docutils/languages, the other in
# docutils/parsers/rst/languages.

"""
Finnish-language mappings for language-dependent features of
reStructuredText.
"""

__docformat__ = 'reStructuredText'


directives = {
      # language-dependent: fixed
      u'huomio': u'attention',
      u'varo': u'caution',
      u'code (translation required)': 'code',
      u'vaara': u'danger',
      u'virhe': u'error',
      u'vihje': u'hint',
      u't\u00e4rke\u00e4\u00e4': u'important',
      u'huomautus': u'note',
      u'neuvo': u'tip',
      u'varoitus': u'warning',
      u'kehotus': u'admonition',
      u'sivupalkki': u'sidebar',
      u'aihe': u'topic',
      u'rivi': u'line-block',
      u'tasalevyinen': u'parsed-literal',
      u'ohje': u'rubric',
      u'epigraafi': u'epigraph',
      u'kohokohdat': u'highlights',
      u'lainaus': u'pull-quote',
      u'taulukko': u'table',
      u'csv-taulukko': u'csv-table',
      u'list-table (translation required)': 'list-table',
      u'compound (translation required)': 'compound',
      u'container (translation required)': 'container',
      #u'kysymykset': u'questions',
      u'meta': u'meta',
      'math (translation required)': 'math',
      #u'kuvakartta': u'imagemap',
      u'kuva': u'image',
      u'kaavio': u'figure',
      u'sis\u00e4llyt\u00e4': u'include',
      u'raaka': u'raw',
      u'korvaa': u'replace',
      u'unicode': u'unicode',
      u'p\u00e4iv\u00e4ys': u'date',
      u'luokka': u'class',
      u'rooli': u'role',
      u'default-role (translation required)': 'default-role',
      u'title (translation required)': 'title',
      u'sis\u00e4llys': u'contents',
      u'kappale': u'sectnum',
      u'header (translation required)': 'header',
      u'footer (translation required)': 'footer',
      #u'alaviitteet': u'footnotes',
      #u'viitaukset': u'citations',
      u'target-notes (translation required)': u'target-notes'}
"""Finnish name to registered (in directives/__init__.py) directive name
mapping."""

roles = {
    # language-dependent: fixed
    u'lyhennys': u'abbreviation',
    u'akronyymi': u'acronym',
    u'kirjainsana': u'acronym',
    u'code (translation required)': 'code',
    u'hakemisto': u'index',
    u'luettelo': u'index',
    u'alaindeksi': u'subscript',
    u'indeksi': u'subscript',
    u'yl\u00e4indeksi': u'superscript',
    u'title-reference (translation required)': u'title-reference',
    u'title (translation required)': u'title-reference',
    u'pep-reference (translation required)': u'pep-reference',
    u'rfc-reference (translation required)': u'rfc-reference',
    u'korostus': u'emphasis',
    u'vahvistus': u'strong',
    u'tasalevyinen': u'literal',
    'math (translation required)': 'math',
    u'named-reference (translation required)': u'named-reference',
    u'anonymous-reference (translation required)': u'anonymous-reference',
    u'footnote-reference (translation required)': u'footnote-reference',
    u'citation-reference (translation required)': u'citation-reference',
    u'substitution-reference (translation required)': u'substitution-reference',
    u'kohde': u'target',
    u'uri-reference (translation required)': u'uri-reference',
    u'raw (translation required)': 'raw',}
"""Mapping of Finnish role names to canonical role names for interpreted text.
"""



# -*- coding: utf-8 -*-
# $Id: ko.py 8253 2019-04-15 10:01:10Z milde $
# Author: Thomas SJ Kang <thomas.kangsj@ujuc.kr>
# Copyright: This module has been placed in the public domain.

# New language mappings are welcome.  Before doing a new translation, please
# read <http://docutils.sf.net/docs/howto/i18n.html>.  Two files must be
# translated for each language: one in docutils/languages, the other in
# docutils/parsers/rst/languages.

"""
Korean-language mappings for language-dependent features of
reStructuredText.
"""

__docformat__ = 'reStructuredText'


directives = {
      # language-dependent: fixed
      u'집중': 'attention',
      u'주의': 'caution',
      u'코드': 'code',
      u'코드-블록': 'code',
      u'소스코드': 'code',
      u'위험': 'danger',
      u'오류': 'error',
      u'실마리': 'hint',
      u'중요한': 'important',
      u'비고': 'note',
      u'팁': 'tip',
      u'경고': 'warning',
      u'권고': 'admonition',
      u'사이드바': 'sidebar',
      u'주제': 'topic',
      u'라인-블록': 'line-block',
      u'파싱된-리터럴': 'parsed-literal',
      u'지시문': 'rubric',
      u'제명': 'epigraph',
      u'하이라이': 'highlights',
      u'발췌문': 'pull-quote',
      u'합성어': 'compound',
      u'컨테이너': 'container',
      #u'질문': 'questions',
      u'표': 'table',
      u'csv-표': 'csv-table',
      u'list-표': 'list-table',
      #u'qa': 'questions',
      #u'faq': 'questions',
      u'메타': 'meta',
      u'수학': 'math',
      #u'이미지맵': 'imagemap',
      u'이미지': 'image',
      u'도표': 'figure',
      u'포함': 'include',
      'raw': 'raw',
      u'대신하다': 'replace',
      'unicode': 'unicode',
      u'날짜': 'date',
      'class': 'class',
      u'역할': 'role',
      u'기본-역할': 'default-role',
      u'제목': 'title',
      u'내용': 'contents',
      'sectnum': 'sectnum',
      u'섹션-번호-매기기': 'sectnum',
      u'머리말': 'header',
      u'꼬리말': 'footer',
      #u'긱주': 'footnotes',
      #u'인용구': 'citations',
      u'목표-노트': 'target-notes',
      u'restructuredtext 테스트 지시어': 'restructuredtext-test-directive'}
"""Korean name to registered (in directives/__init__.py) directive name
mapping."""

roles = {
    # language-dependent: fixed
    u'약어': 'abbreviation',
    u'ab': 'abbreviation',
    u'두음문자': 'acronym',
    u'ac': 'acronym',
    u'코드': 'code',
    u'색인': 'index',
    u'i': 'index',
    u'다리-글자': 'subscript',
    u'sub': 'subscript',
    u'어깨-글자': 'superscript',
    u'sup': 'superscript',
    u'제목-참조': 'title-reference',
    u'제목': 'title-reference',
    u't': 'title-reference',
    u'pep-참조': 'pep-reference',
    u'pep': 'pep-reference',
    u'rfc-참조': 'rfc-reference',
    u'rfc': 'rfc-reference',
    u'강조': 'emphasis',
    u'굵게': 'strong',
    u'기울기': 'literal',
    u'수학': 'math',
    u'명명된-참조': 'named-reference',
    u'익명-참조': 'anonymous-reference',
    u'각주-참조': 'footnote-reference',
    u'인용-참조': 'citation-reference',
    u'대리-참조': 'substitution-reference',
    u'대상': 'target',
    u'uri-참조': 'uri-reference',
    u'uri': 'uri-reference',
    u'url': 'uri-reference',
    'raw': 'raw',}
"""Mapping of Korean role names to canonical role names for interpreted text.
"""



# $Id: eo.py 4564 2006-05-21 20:44:42Z wiemann $
# Author: Marcelo Huerta San Martin <richieadler@users.sourceforge.net>
# Copyright: This module has been placed in the public domain.

# New language mappings are welcome.  Before doing a new translation, please
# read <http://docutils.sf.net/docs/howto/i18n.html>.  Two files must be
# translated for each language: one in docutils/languages, the other in
# docutils/parsers/rst/languages.

"""
Esperanto-language mappings for language-dependent features of Docutils.
"""

__docformat__ = 'reStructuredText'

labels = {
      # fixed: language-dependent
      'author': u'A\u016dtoro',
      'authors': u'A\u016dtoroj',
      'organization': u'Organizo',
      'address': u'Adreso',
      'contact': u'Kontakto',
      'version': u'Versio',
      'revision': u'Revido',
      'status': u'Stato',
      'date': u'Dato',
      # 'copyright': u'Kopirajto',
      'copyright': u'A\u016dtorrajto',
      'dedication': u'Dedi\u0109o',
      'abstract': u'Resumo',
      'attention': u'Atentu!',
      'caution': u'Zorgu!',
      'danger': u'DAN\u011cERO!',
      'error': u'Eraro',
      'hint': u'Spuro',
      'important': u'Grava',
      'note': u'Noto',
      'tip': u'Helpeto',
      'warning': u'Averto',
      'contents': u'Enhavo'}
"""Mapping of node class name to label text."""

bibliographic_fields = {
      # language-dependent: fixed
      'a\u016dtoro': 'author',
      'a\u016dtoroj': 'authors',
      'organizo': 'organization',
      'adreso': 'address',
      'kontakto': 'contact',
      'versio': 'version',
      'revido': 'revision',
      'stato': 'status',
      'dato': 'date',
      'a\u016dtorrajto': 'copyright',
      'dedi\u0109o': 'dedication',
      'resumo': 'abstract'}
"""Esperanto (lowcased) to canonical name mapping for bibliographic fields."""

author_separators = [';', ',']
"""List of separator strings for the 'Authors' bibliographic field. Tried in
order."""
